@@ -92,8 +92,9 @@ class BaseSpool(abc.ABC):
 
 
 class DataFrameSpool(BaseSpool):
-    """A spool whose contents are managed by a dataframe."""
-
+    """
+    An abstract class for spools whose contents are managed by a dataframe.
+    """
     # A dataframe which represents contents as they will be output
     _df: pd.DataFrame = CacheDescriptor("_cache", "_get_df")
     # A dataframe which shows patches in the source
